@@ -12,6 +12,9 @@
 #include "colortable.h"
 #include "fastrand.h"
 
+#include <X11/Xlib.h>
+#include <SDL_syswm.h>
+
 #include "config.h"
 
 // Global variables set in this file...
@@ -714,6 +717,26 @@ extern "C" void CleanUp(void)
 	SDL_Quit();
 }
 
+#ifdef MAEMO
+int MaemoEnableZoomKeys()
+{
+	SDL_SysWMinfo info;
+	SDL_VERSION(&info.version);                                                                                                                          
+	if ( SDL_GetWMInfo(&info) ) {                                                                                                                        
+		unsigned long val = 1;
+		Window w;
+		Display *d = info.info.x11.display;
+		Atom atom = XInternAtom(d, "_HILDON_ZOOM_KEY_ATOM", 0);
+		w=info.info.x11.window;
+		XChangeProperty(d, w, atom, XA_INTEGER, 32, PropModeReplace, (unsigned char *)&val,1);
+		w=info.info.x11.fswindow;
+		XChangeProperty(d, w, atom, XA_INTEGER, 32, PropModeReplace, (unsigned char *)&val,1);
+		w=info.info.x11.wmwindow;
+		XChangeProperty(d, w, atom, XA_INTEGER, 32, PropModeReplace, (unsigned char *)&val,1);
+	}
+}
+#endif
+
 /* ----------------------------------------------------------------- */
 /* -- Perform some initializations and report failure if we choke */
 int DoInitializations(Uint32 video_flags)
@@ -803,6 +826,7 @@ int DoInitializations(Uint32 video_flags)
 #ifdef MAEMO
 	/* Hide mouse */
 	SDL_ShowCursor(0);
+	MaemoEnableZoomKeys();
 #endif
 	/* Do the Ambrosia Splash screen */
 	screen->Clear();
