@@ -474,9 +474,11 @@ Player::DoPause(int r)
 	}
 	break;
 	case 1:
-		sound->PlaySound(gPauseSound, 5);
 		gPaused=1;
 	break;
+	case 2:
+		gPaused=0;
+	break;
 	}
 }
 
@@ -495,12 +497,20 @@ Player::HandleKeys(void)
 			case KEY_PRESS:
 				/* Only handle Pause and Abort while dead */
 				if ( ! Alive() || Exploding ) {
-					if ( inbuf[++i] == PAUSE_KEY ) {
+					switch(inbuf[++i]) {
+					case PAUSE_KEY:
 						DoPause(0);
+					break;
+					case HALT_KEY:
+						DoPause(1);
+					break;
+					case UNHALT_KEY:
+						DoPause(2);
+					break;
 					}
 					if ( inbuf[i] == ABORT_KEY )
 						gGameOn = 0;
-					break;
+					continue;
 				}
 				/* Regular key press handling */
 				switch(inbuf[++i]) {
@@ -522,6 +532,12 @@ Player::HandleKeys(void)
 					case PAUSE_KEY:
 						DoPause(0);
 						break;
+					case HALT_KEY:
+						DoPause(1);
+						break;
+					case UNHALT_KEY:
+						DoPause(2);
+						break;
 					case ABORT_KEY:
 						gGameOn = 0;
 						break;
